@@ -33,37 +33,50 @@ def sagemaker_env_args(config):
     return args
 """
 
+
 def sagemaker_env_args(args: argparse.Namespace, config: SageMakerTrainingConfig):
     """
     Check for ``SM_TRAINING_ENV`` environment variable and use it to override arguments.
     """
     sm_env = os.getenv('SM_TRAINING_ENV', None)
+    kwargs = vars(args)
     if sm_env:
-        kwargs = vars(args)
+        print("Detected SageMaker environment")
         data = json.loads(sm_env)
         ci = data.get('channel_input_dirs', None)
         if ci:
-            aux = {}
             for k in config.inputs.keys():
                 v = ci.get(k, None)
                 if v:
-                    aux[k] = v
-            kwargs.update(aux)
-        output_dir = data.get('output_dir', None)
+                    kwargs[k] = v
+                    print("SageMaker input [{}]: [{}]".format(k, v))
+                else:
+                    del kwargs[k]
+        else:
+            for k in config.inputs.keys():
+                del kwargs[k]
+        output_dir = data.get('output_data_dir', None)
         if output_dir:
             kwargs['output_dir'] = output_dir
+            print("SageMaker output_dir: [{}]".format(output_dir))
         model_dir = data.get('model_dir', None)
         if model_dir:
             kwargs['model_dir'] = model_dir
+            print("SageMaker model_dir: [{}]".format(model_dir))
+        job_name = data.get('job_name',None)
+        if job_name:
+            kwargs['sagemaker_job_name'] = job_name
+            print("SageMaker job_name: [{}]".format(job_name))
         kwargs['sagemaker_run'] = False
-        new_args = argparse.Namespace(
-            **kwargs
-        )
-        print("Original args: {}".format(args))
-        print("Updated args: {}".format(new_args))
-        return new_args
+        kwargs['is_sagemaker']=True
     else:
-        return args
+        kwargs['is_sagemaker']=False
+    new_args = argparse.Namespace(
+        **kwargs
+    )
+    #print("Original args: {}".format(args))
+    #print("Updated args: {}".format(new_args))
+    return new_args
 
 
 def sagemaker_training_args(
@@ -248,7 +261,10 @@ def sagemaker_training_args(
     sagemaker_training_model_args(parser=parser, model_dir=model_dir)
     sagemaker_training_output_args(parser=parser, output_dir=output_dir)
     sagemaker_training_checkpoint_args(
-        parser=parser, checkpoint_dir=checkpoint_dir, checkpoint_s3=checkpoint_s3,
+        parser=parser,
+        checkpoint_dir=checkpoint_dir,
+        checkpoint_s3=checkpoint_s3,
+        checkpoint_container=checkpoint_container,
         enable_sagemaker=enable_sagemaker)
     sagemaker_training_channel_args(parser=parser, inputs=inputs)
     if additional_arguments:
@@ -259,7 +275,6 @@ def sagemaker_training_args(
     return SageMakerTrainingConfig(inputs=inputs, dependencies=dependencies)
 
 
-
 def sagemaker_training_output_args(parser: argparse.ArgumentParser, output_dir):
     output_dir = os.environ.get('SM_OUTPUT_DIR', output_dir)
     parser.add_argument('--output-dir', type=str,
